@@ -25,16 +25,16 @@ import (
 	"log/slog"
 	"testing"
 
-	"github.com/specterops/bloodhound/analysis"
-	ad2 "github.com/specterops/bloodhound/analysis/ad"
-	"github.com/specterops/bloodhound/analysis/impact"
-	"github.com/specterops/bloodhound/dawgs/graph"
-	"github.com/specterops/bloodhound/dawgs/ops"
-	"github.com/specterops/bloodhound/dawgs/query"
-	"github.com/specterops/bloodhound/graphschema"
-	"github.com/specterops/bloodhound/graphschema/ad"
-	"github.com/specterops/bloodhound/graphschema/common"
-	"github.com/specterops/bloodhound/src/test/integration"
+	"github.com/specterops/bloodhound/cmd/api/src/test/integration"
+	"github.com/specterops/bloodhound/packages/go/analysis"
+	ad2 "github.com/specterops/bloodhound/packages/go/analysis/ad"
+	"github.com/specterops/bloodhound/packages/go/analysis/impact"
+	"github.com/specterops/bloodhound/packages/go/graphschema"
+	"github.com/specterops/bloodhound/packages/go/graphschema/ad"
+	"github.com/specterops/bloodhound/packages/go/graphschema/common"
+	"github.com/specterops/dawgs/graph"
+	"github.com/specterops/dawgs/ops"
+	"github.com/specterops/dawgs/query"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -191,11 +191,12 @@ func TestPostNTLMRelaySMB(t *testing.T) {
 						start, end, err := ops.FetchRelationshipNodes(tx, result)
 						require.NoError(t, err)
 
-						if start.ID == harness.NTLMCoerceAndRelayNTLMToSMB.Group2.ID {
+						switch start.ID {
+						case harness.NTLMCoerceAndRelayNTLMToSMB.Group2.ID:
 							assert.Equal(t, end.ID, harness.NTLMCoerceAndRelayNTLMToSMB.Computer9.ID)
-						} else if start.ID == harness.NTLMCoerceAndRelayNTLMToSMB.Group1.ID {
+						case harness.NTLMCoerceAndRelayNTLMToSMB.Group1.ID:
 							assert.Equal(t, end.ID, harness.NTLMCoerceAndRelayNTLMToSMB.Computer2.ID)
-						} else {
+						default:
 							require.FailNow(t, "unrecognized start node id")
 						}
 					}
@@ -391,13 +392,14 @@ func TestPostCoerceAndRelayNTLMToLDAP(t *testing.T) {
 						dcSet, err := ad2.GetVulnerableDomainControllersForRelayNTLMtoLDAP(context.Background(), db, result)
 						require.NoError(t, err)
 
-						if start.ID == harness.NTLMCoerceAndRelayNTLMToLDAP.Group1.ID {
+						switch start.ID {
+						case harness.NTLMCoerceAndRelayNTLMToLDAP.Group1.ID:
 							assert.Equal(t, end.ID, harness.NTLMCoerceAndRelayNTLMToLDAP.Computer2.ID)
 							assert.True(t, dcSet.ContainsID(harness.NTLMCoerceAndRelayNTLMToLDAP.Computer1.ID))
-						} else if start.ID == harness.NTLMCoerceAndRelayNTLMToLDAP.Group5.ID {
+						case harness.NTLMCoerceAndRelayNTLMToLDAP.Group5.ID:
 							assert.Equal(t, end.ID, harness.NTLMCoerceAndRelayNTLMToLDAP.Computer7.ID)
 							assert.True(t, dcSet.ContainsID(harness.NTLMCoerceAndRelayNTLMToLDAP.Computer6.ID))
-						} else {
+						default:
 							require.FailNow(t, "unrecognized start node id")
 						}
 
@@ -464,15 +466,16 @@ func TestPostCoerceAndRelayNTLMToLDAP(t *testing.T) {
 						dcSet, err := ad2.GetVulnerableDomainControllersForRelayNTLMtoLDAPS(context.Background(), db, result)
 						require.NoError(t, err)
 
-						if start.ID == harness.NTLMCoerceAndRelayNTLMToLDAPS.Group1.ID {
+						switch start.ID {
+						case harness.NTLMCoerceAndRelayNTLMToLDAPS.Group1.ID:
 							if end.ID != harness.NTLMCoerceAndRelayNTLMToLDAPS.Computer2.ID && end.ID != harness.NTLMCoerceAndRelayNTLMToLDAPS.Computer5.ID {
 								require.FailNow(t, "unrecognized end node associated with Group1")
 							}
 							assert.True(t, dcSet.ContainsID(harness.NTLMCoerceAndRelayNTLMToLDAPS.Computer1.ID))
-						} else if start.ID == harness.NTLMCoerceAndRelayNTLMToLDAPS.Group5.ID {
+						case harness.NTLMCoerceAndRelayNTLMToLDAPS.Group5.ID:
 							assert.Equal(t, end.ID, harness.NTLMCoerceAndRelayNTLMToLDAPS.Computer7.ID)
 							assert.True(t, dcSet.ContainsID(harness.NTLMCoerceAndRelayNTLMToLDAPS.Computer6.ID))
-						} else {
+						default:
 							require.FailNow(t, "unrecognized start node id")
 						}
 					}
