@@ -19,8 +19,8 @@ package apiclient
 import (
 	"net/http"
 
-	"github.com/specterops/bloodhound/src/api"
-	"github.com/specterops/bloodhound/src/model"
+	"github.com/specterops/bloodhound/cmd/api/src/api"
+	"github.com/specterops/bloodhound/cmd/api/src/model"
 )
 
 func (s Client) RequestAnalysis() error {
