@@ -20,16 +20,19 @@ package database_test
 
 import (
 	"context"
+	"fmt"
 	"log"
+	"strconv"
 	"testing"
 	"time"
 
 	"github.com/gofrs/uuid"
-	"github.com/specterops/bloodhound/dawgs/graph"
-	"github.com/specterops/bloodhound/src/database"
-	"github.com/specterops/bloodhound/src/database/types/null"
-	"github.com/specterops/bloodhound/src/model"
-	"github.com/specterops/bloodhound/src/test/integration"
+	"github.com/specterops/bloodhound/cmd/api/src/database"
+	"github.com/specterops/bloodhound/cmd/api/src/database/types/null"
+	"github.com/specterops/bloodhound/cmd/api/src/model"
+	"github.com/specterops/bloodhound/cmd/api/src/test/integration"
+	"github.com/specterops/dawgs/graph"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -68,7 +71,7 @@ func TestDatabase_CreateAssetGroupTagSelector(t *testing.T) {
 		require.Equal(t, seed.Value, selector.Seeds[idx].Value)
 	}
 
-	history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+	history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, model.Sort{{Column: "created_at", Direction: model.AscendingSortDirection}}, 0, 0)
 	require.NoError(t, err)
 	require.Len(t, history, 1)
 	require.Equal(t, model.AssetGroupHistoryActionCreateSelector, history[0].Action)
@@ -149,7 +152,7 @@ func TestDatabase_UpdateAssetGroupTagSelector(t *testing.T) {
 	selector.Seeds = updateSeeds
 
 	// call the update function
-	_, err = dbInst.UpdateAssetGroupTagSelector(testCtx, updateActor, selector)
+	_, err = dbInst.UpdateAssetGroupTagSelector(testCtx, updateActor.ID.String(), updateActor.EmailAddress.ValueOrZero(), selector)
 	require.NoError(t, err)
 
 	readBackSelector, err := dbInst.GetAssetGroupTagSelectorBySelectorId(testCtx, selector.ID)
@@ -173,25 +176,24 @@ func TestDatabase_UpdateAssetGroupTagSelector(t *testing.T) {
 
 func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 	var (
-		dbInst = integration.SetupDB(t)
-
-		testCtx             = context.Background()
-		tagTypeTier         = model.AssetGroupTagTypeTier
-		tagTypeLabel        = model.AssetGroupTagTypeLabel
-		testActor           = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
-		testName            = "test tag name"
-		testName2           = "test2 tag name"
-		testName3           = "test3 tag name"
-		testName4           = "test4 tag name"
-		testDescription     = "test tag description"
-		position            = null.Int32{}
-		shiftedPosition     = null.Int32From(2)
-		shiftedPosition2    = null.Int32From(3)
-		requireCertifyTier  = null.BoolFrom(true)
-		requireCertifyLabel = null.Bool{}
+		testCtx                = context.Background()
+		tagTypeTier            = model.AssetGroupTagTypeTier
+		tagTypeLabel           = model.AssetGroupTagTypeLabel
+		testActor              = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
+		testName               = "test tag name"
+		testName2              = "test2 tag name"
+		testName3              = "test3 tag name"
+		testName4              = "test4 tag name"
+		testDescription        = "test tag description"
+		position               = null.Int32{}
+		requireCertifyTier     = null.BoolFrom(true)
+		requireCertifyLabel    = null.Bool{}
+		sortAscendingCreatedAt = model.Sort{{Column: "created_at", Direction: model.AscendingSortDirection}}
 	)
 
 	t.Run("successfully creates tier", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
+
 		tag, err := dbInst.CreateAssetGroupTag(testCtx, tagTypeTier, testActor, testName, testDescription, position, requireCertifyTier)
 		require.NoError(t, err)
 		require.Equal(t, tagTypeTier, tag.Type)
@@ -205,6 +207,7 @@ func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 		require.Equal(t, testDescription, tag.Description)
 		require.Equal(t, null.Int32From(2), tag.Position)
 		require.Equal(t, null.BoolFrom(true), tag.RequireCertify)
+		require.Equal(t, null.BoolFrom(false), tag.AnalysisEnabled)
 
 		tag, err = dbInst.GetAssetGroupTag(testCtx, tag.ID)
 		require.NoError(t, err)
@@ -219,15 +222,18 @@ func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 		require.Equal(t, testDescription, tag.Description)
 		require.Equal(t, null.Int32From(2), tag.Position)
 		require.Equal(t, null.BoolFrom(true), tag.RequireCertify)
+		require.Equal(t, null.BoolFrom(false), tag.AnalysisEnabled)
 
 		// verify history record was also created
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
 		require.Len(t, history, 1)
 		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[0].Action)
 	})
 
 	t.Run("successfully creates label", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
+
 		tag, err := dbInst.CreateAssetGroupTag(testCtx, tagTypeLabel, testActor, testName2, testDescription, position, requireCertifyLabel)
 		require.NoError(t, err)
 		require.Equal(t, tagTypeLabel, tag.Type)
@@ -241,6 +247,7 @@ func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 		require.Equal(t, testDescription, tag.Description)
 		require.Equal(t, null.Int32{}, tag.Position)
 		require.Equal(t, null.Bool{}, tag.RequireCertify)
+		require.Equal(t, null.Bool{}, tag.AnalysisEnabled)
 
 		tag, err = dbInst.GetAssetGroupTag(testCtx, tag.ID)
 		require.NoError(t, err)
@@ -255,78 +262,47 @@ func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 		require.Equal(t, testDescription, tag.Description)
 		require.Equal(t, null.Int32{}, tag.Position)
 		require.Equal(t, null.Bool{}, tag.RequireCertify)
+		require.Equal(t, null.Bool{}, tag.AnalysisEnabled)
 	})
 
 	t.Run("successfully creates and shifts tiers", func(t *testing.T) {
-		tag, err := dbInst.CreateAssetGroupTag(testCtx, tagTypeTier, testActor, testName3, testDescription, shiftedPosition, requireCertifyTier)
+		var (
+			position2 = null.Int32From(2)
+			position3 = null.Int32From(3)
+			dbInst    = integration.SetupDB(t)
+		)
+
+		tag, err := dbInst.CreateAssetGroupTag(testCtx, tagTypeTier, testActor, testName3, testDescription, position2, requireCertifyTier)
 		require.NoError(t, err)
-		require.Equal(t, tagTypeTier, tag.Type)
-		require.False(t, tag.CreatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag.CreatedBy)
-		require.False(t, tag.UpdatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag.UpdatedBy)
-		require.Empty(t, tag.DeletedAt)
-		require.Empty(t, tag.DeletedBy)
-		require.Equal(t, testName3, tag.Name)
-		require.Equal(t, testDescription, tag.Description)
-		require.Equal(t, null.Int32From(2), tag.Position)
-		require.Equal(t, null.BoolFrom(true), tag.RequireCertify)
 
 		tag, err = dbInst.GetAssetGroupTag(testCtx, tag.ID)
 		require.NoError(t, err)
-		require.Equal(t, tagTypeTier, tag.Type)
-		require.False(t, tag.CreatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag.CreatedBy)
-		require.False(t, tag.UpdatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag.UpdatedBy)
-		require.Empty(t, tag.DeletedAt)
-		require.Empty(t, tag.DeletedBy)
-		require.Equal(t, testName3, tag.Name)
-		require.Equal(t, testDescription, tag.Description)
-		require.Equal(t, null.Int32From(2), tag.Position)
-		require.Equal(t, null.BoolFrom(true), tag.RequireCertify)
+		require.Equal(t, position2, tag.Position)
 
-		tag2, err := dbInst.CreateAssetGroupTag(testCtx, tagTypeTier, testActor, testName4, testDescription, shiftedPosition2, requireCertifyTier)
+		// Create another tag at an existing position, forcing the first tag down
+		tag2, err := dbInst.CreateAssetGroupTag(testCtx, tagTypeTier, testActor, testName4, testDescription, position2, requireCertifyTier)
 		require.NoError(t, err)
-		require.Equal(t, tagTypeTier, tag2.Type)
-		require.False(t, tag2.CreatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag2.CreatedBy)
-		require.False(t, tag2.UpdatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag2.UpdatedBy)
-		require.Empty(t, tag2.DeletedAt)
-		require.Empty(t, tag2.DeletedBy)
-		require.Equal(t, testName4, tag2.Name)
-		require.Equal(t, testDescription, tag.Description)
-		require.Equal(t, null.Int32From(3), tag2.Position)
-		require.Equal(t, null.BoolFrom(true), tag.RequireCertify)
 
 		tag2, err = dbInst.GetAssetGroupTag(testCtx, tag2.ID)
 		require.NoError(t, err)
-		require.Equal(t, tagTypeTier, tag2.Type)
-		require.False(t, tag2.CreatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag.CreatedBy)
-		require.False(t, tag2.UpdatedAt.IsZero())
-		require.Equal(t, testActor.ID.String(), tag2.UpdatedBy)
-		require.Empty(t, tag2.DeletedAt)
-		require.Empty(t, tag2.DeletedBy)
-		require.Equal(t, testName4, tag2.Name)
-		require.Equal(t, testDescription, tag2.Description)
-		require.Equal(t, null.Int32From(3), tag2.Position)
-		require.Equal(t, null.BoolFrom(true), tag2.RequireCertify)
+		require.Equal(t, position2, tag2.Position)
+
+		tag, err = dbInst.GetAssetGroupTag(testCtx, tag.ID)
+		require.NoError(t, err)
+		require.Equal(t, position3, tag.Position)
 
 		// verify history record was also created and shifted
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
-		require.Len(t, history, 6)
+		require.Len(t, history, 3)
 		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[0].Action)
-		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[1].Action)
-		require.Equal(t, model.AssetGroupHistoryActionUpdateTag, history[2].Action)
-		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[3].Action)
-		require.Equal(t, model.AssetGroupHistoryActionUpdateTag, history[4].Action)
-		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[5].Action)
+		require.Equal(t, model.AssetGroupHistoryActionUpdateTag, history[1].Action)
+		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[2].Action)
 	})
 
 	t.Run("Non existant tag errors out", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
+
 		_, err := dbInst.GetAssetGroupTag(testCtx, 1234)
 		require.Error(t, err)
 	})
@@ -335,12 +311,13 @@ func TestDatabase_CreateAssetGroupTag(t *testing.T) {
 
 func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 	var (
-		dbInst    = integration.SetupDB(t)
 		testCtx   = context.Background()
 		testActor = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
 	)
 
 	t.Run("updates regular fields successfully", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
+
 		origTier, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeTier,
@@ -365,7 +342,7 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 		require.Equal(t, toUpdate.RequireCertify, updatedTier.RequireCertify)
 
 		// verify history records were created
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, model.Sort{{Column: "created_at", Direction: model.AscendingSortDirection}}, 0, 0)
 		require.NoError(t, err)
 		require.Len(t, history, 2)
 		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[0].Action)
@@ -373,6 +350,7 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 	})
 
 	t.Run("returns error for duplicate name", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
 		_, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeTier,
@@ -402,6 +380,7 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 	})
 
 	t.Run("requires position set for tier", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
 		tier, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeTier,
@@ -420,6 +399,7 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 	})
 
 	t.Run("position is invalid for non-tier", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
 		tag, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeLabel,
@@ -434,10 +414,11 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 		tag.Position = null.Int32From(2)
 
 		_, err = dbInst.UpdateAssetGroupTag(testCtx, testActor, tag)
-		require.ErrorContains(t, err, "position and require_certify are limited to tiers only")
+		require.ErrorContains(t, err, "position, require_certify, and analysis_enabled are limited to tiers only")
 	})
 
 	t.Run("require_certify is invalid for non-tier", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
 		tag, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeLabel,
@@ -452,10 +433,11 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 		tag.RequireCertify = null.BoolFrom(false)
 
 		_, err = dbInst.UpdateAssetGroupTag(testCtx, testActor, tag)
-		require.ErrorContains(t, err, "position and require_certify are limited to tiers only")
+		require.ErrorContains(t, err, "position, require_certify, and analysis_enabled are limited to tiers only")
 	})
 
 	t.Run("blocks updating to position 1", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
 		tag, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeTier,
@@ -474,6 +456,7 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 	})
 
 	t.Run("blocks updating to invalid positions", func(t *testing.T) {
+		dbInst := integration.SetupDB(t)
 		tag, err := dbInst.CreateAssetGroupTag(
 			testCtx,
 			model.AssetGroupTagTypeTier,
@@ -501,8 +484,9 @@ func TestDatabase_UpdateAssetGroupTag(t *testing.T) {
 
 func TestDatabase_UpdateAssetGroupTag_shifting(t *testing.T) {
 	var (
-		testCtx   = context.Background()
-		testActor = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
+		testCtx                = context.Background()
+		testActor              = model.User{Unique: model.Unique{ID: uuid.FromStringOrNil("01234567-9012-4567-9012-456789012345")}}
+		sortAscendingCreatedAt = model.Sort{{Column: "created_at", Direction: model.AscendingSortDirection}}
 	)
 
 	t.Run("shifts tier higher successfully", func(t *testing.T) {
@@ -549,7 +533,7 @@ func TestDatabase_UpdateAssetGroupTag_shifting(t *testing.T) {
 		)
 
 		// verify history records were created
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
 		require.GreaterOrEqual(t, len(history), 2)
 		n := len(history) - 2
@@ -603,7 +587,7 @@ func TestDatabase_UpdateAssetGroupTag_shifting(t *testing.T) {
 		)
 
 		// verify history records were created
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
 		require.GreaterOrEqual(t, len(history), 2)
 		n := len(history) - 2
@@ -616,22 +600,23 @@ func TestDatabase_UpdateAssetGroupTag_shifting(t *testing.T) {
 
 func TestDatabase_DeleteAssetGroupTag(t *testing.T) {
 	var (
-		testCtx            = context.Background()
-		userID, _          = uuid.NewV4()
-		userID2, _         = uuid.NewV4()
-		userID4, _         = uuid.NewV4()
-		testUser           = model.User{Unique: model.Unique{ID: userID}}
-		testUser2          = model.User{Unique: model.Unique{ID: userID2}}
-		testUser4          = model.User{Unique: model.Unique{ID: userID4}}
-		testName           = "test tag name"
-		testName2          = "test tag name2"
-		testName4          = "test tag name4"
-		testDescription    = "test tag description"
-		testDescription2   = "test tag description2"
-		testDescription4   = "test tag description4"
-		position           = null.Int32From(2)
-		position2          = null.Int32From(3)
-		requireCertifyTier = null.BoolFrom(true)
+		testCtx                = context.Background()
+		userID, _              = uuid.NewV4()
+		userID2, _             = uuid.NewV4()
+		userID4, _             = uuid.NewV4()
+		testUser               = model.User{Unique: model.Unique{ID: userID}}
+		testUser2              = model.User{Unique: model.Unique{ID: userID2}}
+		testUser4              = model.User{Unique: model.Unique{ID: userID4}}
+		testName               = "test tag name"
+		testName2              = "test tag name2"
+		testName4              = "test tag name4"
+		testDescription        = "test tag description"
+		testDescription2       = "test tag description2"
+		testDescription4       = "test tag description4"
+		position               = null.Int32From(2)
+		position2              = null.Int32From(3)
+		requireCertifyTier     = null.BoolFrom(true)
+		sortAscendingCreatedAt = model.Sort{{Column: "created_at", Direction: model.AscendingSortDirection}}
 	)
 
 	getTagOrder := func(orderedTags []model.AssetGroupTag) []int {
@@ -669,7 +654,7 @@ func TestDatabase_DeleteAssetGroupTag(t *testing.T) {
 		require.Equal(t, []int{1, assetGroupTagTier2.ID}, getTagOrder(orderedTagsAfter))
 
 		// verify history records were created
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
 		require.Len(t, history, 4)
 		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[0].Action)
@@ -691,7 +676,7 @@ func TestDatabase_DeleteAssetGroupTag(t *testing.T) {
 		require.NoError(t, err)
 
 		// verify history records were created
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
 		require.Len(t, history, 2)
 		require.Equal(t, model.AssetGroupHistoryActionCreateTag, history[0].Action)
@@ -733,7 +718,7 @@ func TestDatabase_GetAssetGroupTags(t *testing.T) {
 			label2.ID,
 		}
 
-		items, err := dbInst.GetAssetGroupTags(testCtx, model.SQLFilter{SQLString: "type = ?", Params: []any{model.AssetGroupTagTypeLabel}})
+		items, err := dbInst.GetAssetGroupTags(testCtx, model.SQLFilter{SQLString: "type = " + strconv.Itoa(int(model.AssetGroupTagTypeLabel))})
 		require.NoError(t, err)
 		require.GreaterOrEqual(t, len(items), 2)
 		for _, itm := range items {
@@ -751,7 +736,7 @@ func TestDatabase_GetAssetGroupTags(t *testing.T) {
 			tier2.ID,
 		}
 
-		items, err := dbInst.GetAssetGroupTags(testCtx, model.SQLFilter{SQLString: "type = ?", Params: []any{model.AssetGroupTagTypeTier}})
+		items, err := dbInst.GetAssetGroupTags(testCtx, model.SQLFilter{SQLString: "type = " + strconv.Itoa(int(model.AssetGroupTagTypeTier))})
 		require.NoError(t, err)
 		require.GreaterOrEqual(t, len(items), 2)
 		for _, itm := range items {
@@ -849,7 +834,7 @@ func TestDatabase_GetAssetGroupTagSelectorCounts(t *testing.T) {
 	})
 }
 
-func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
+func TestDatabase_GetAssetGroupTagSelectorsBySelectorId(t *testing.T) {
 	var (
 		dbInst        = integration.SetupDB(t)
 		testCtx       = context.Background()
@@ -878,6 +863,7 @@ func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
 		}
 	)
 
+	test_started_at := time.Now()
 	_, err := dbInst.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, test1Selector.Name, test1Selector.Description, isDefault, allowDisable, autoCertify, test1Selector.Seeds)
 	require.NoError(t, err)
 	created_at := time.Now()
@@ -885,7 +871,7 @@ func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
 	require.NoError(t, err)
 
 	t.Run("successfully returns an array of selectors, no filters", func(t *testing.T) {
-		orig_results, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{}, model.SQLFilter{})
+		orig_results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{}, model.SQLFilter{}, 0, 0)
 		require.NoError(t, err)
 
 		results := make(model.AssetGroupTagSelectors, 0, 2)
@@ -922,7 +908,7 @@ func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
 	})
 
 	t.Run("successfully returns an array of seed selector filters", func(t *testing.T) {
-		orig_results, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{}, model.SQLFilter{SQLString: "type = ?", Params: []any{2}})
+		orig_results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{}, model.SQLFilter{SQLString: "type = 2"}, 0, 0)
 		require.NoError(t, err)
 
 		results := make(model.AssetGroupTagSelectors, 0, 1)
@@ -940,7 +926,7 @@ func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
 	})
 
 	t.Run("successfully returns an array of selector filters", func(t *testing.T) {
-		results, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{created_at}}, model.SQLFilter{})
+		results, _, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{created_at}}, model.SQLFilter{}, 0, 0)
 		require.NoError(t, err)
 
 		require.Equal(t, 1, len(results))
@@ -948,6 +934,24 @@ func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
 
 	})
 
+	t.Run("successfully returns an array using the skip param", func(t *testing.T) {
+		results, count, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{test_started_at}}, model.SQLFilter{}, 1, 0)
+		require.NoError(t, err)
+
+		require.Equal(t, 1, len(results))
+		require.Equal(t, 2, count)
+		require.Equal(t, test2Selector.Name, results[0].Name)
+	})
+
+	t.Run("successfully returns an array using the limit param", func(t *testing.T) {
+		results, count, err := dbInst.GetAssetGroupTagSelectorsByTagId(testCtx, 1, model.SQLFilter{SQLString: "created_at >= ?", Params: []any{test_started_at}}, model.SQLFilter{}, 0, 1)
+		require.NoError(t, err)
+
+		require.Equal(t, 1, len(results))
+		require.Equal(t, 2, count)
+		require.Equal(t, test1Selector.Name, results[0].Name)
+	})
+
 }
 
 func TestDatabase_GetSelectorsByMemberId(t *testing.T) {
@@ -994,12 +998,13 @@ func TestDatabase_DeleteAssetGroupTagSelector(t *testing.T) {
 			{Type: model.SelectorTypeObjectId, Value: "ObjectID1234"},
 			{Type: model.SelectorTypeObjectId, Value: "ObjectID5678"},
 		}
+		sortAscendingCreatedAt = model.Sort{{Column: "created_at", Direction: model.AscendingSortDirection}}
 	)
 
 	selector, err := dbInst.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, testName, testDescription, isDefault, allowDisable, autoCertify, testSeeds)
 	require.NoError(t, err)
 
-	history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+	history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 	require.NoError(t, err)
 	require.Len(t, history, 1)
 	require.Equal(t, model.AssetGroupHistoryActionCreateSelector, history[0].Action)
@@ -1013,9 +1018,74 @@ func TestDatabase_DeleteAssetGroupTagSelector(t *testing.T) {
 		require.EqualError(t, err, "entity not found")
 
 		// verify a history record was created for the delete action
-		history, err := dbInst.GetAssetGroupHistoryRecords(testCtx)
+		history, _, err := dbInst.GetAssetGroupHistoryRecords(testCtx, model.SQLFilter{}, sortAscendingCreatedAt, 0, 0)
 		require.NoError(t, err)
 		require.Len(t, history, 2)
 		require.Equal(t, model.AssetGroupHistoryActionDeleteSelector, history[1].Action)
 	})
 }
+
+func TestDatabase_GetOrderedAssetGroupTagTiers(t *testing.T) {
+	var (
+		testCtx      = context.Background()
+		dbInst, user = initAndCreateUser(t)
+		tagToDelete  model.AssetGroupTag
+	)
+
+	// Create tiers
+	for i := range 5 {
+		tag, err := dbInst.CreateAssetGroupTag(testCtx, model.AssetGroupTagTypeTier, user, fmt.Sprintf("tag %d", i), "", null.Int32From(int32(i+2)), null.Bool{})
+		require.NoError(t, err)
+		// Delete the fourth entry to ensure positions are changed
+		if i == 3 {
+			tagToDelete = tag
+		}
+	}
+
+	// Delete a tier to ensure deleted tiers are skipped
+	err := dbInst.DeleteAssetGroupTag(testCtx, user, tagToDelete)
+	require.NoError(t, err)
+
+	orderedTags, err := dbInst.GetOrderedAssetGroupTagTiers(testCtx)
+	require.NoError(t, err)
+	for i, tag := range orderedTags {
+		assert.Equal(t, model.AssetGroupTagTypeTier, tag.Type)
+		assert.True(t, tag.DeletedAt.IsZero())
+		assert.EqualValues(t, i+1, tag.Position.ValueOrZero())
+	}
+}
+
+func TestDatabase_GetAssetGroupTagSelectors(t *testing.T) {
+	var (
+		dbInst        = integration.SetupDB(t)
+		testCtx       = context.Background()
+		isDefault     = false
+		allowDisable  = true
+		autoCertify   = null.BoolFrom(false)
+		test1Selector = model.AssetGroupTagSelector{
+			Name:        "test selector name",
+			Description: "test description",
+			Seeds: []model.SelectorSeed{
+				{Type: model.SelectorTypeObjectId, Value: "ObjectID1234"},
+			},
+		}
+		test2Selector = model.AssetGroupTagSelector{
+			Name:        "test2 selector name",
+			Description: "test2 description",
+			Seeds: []model.SelectorSeed{
+				{Type: model.SelectorTypeCypher, Value: "MATCH (n:User) RETURN n LIMIT 1;"},
+			},
+		}
+	)
+
+	_, err := dbInst.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, test1Selector.Name, test1Selector.Description, isDefault, allowDisable, autoCertify, test1Selector.Seeds)
+	require.NoError(t, err)
+	_, err = dbInst.CreateAssetGroupTagSelector(testCtx, 1, model.User{}, test2Selector.Name, test2Selector.Description, isDefault, allowDisable, autoCertify, test2Selector.Seeds)
+	require.NoError(t, err)
+
+	t.Run("returns all selectors", func(t *testing.T) {
+		items, err := dbInst.GetAssetGroupTagSelectors(testCtx, model.SQLFilter{}, 0)
+		require.NoError(t, err)
+		require.GreaterOrEqual(t, len(items), 2)
+	})
+}
