@@ -21,13 +21,13 @@ import (
 	"strings"
 	"time"
 
-	_ "github.com/specterops/bloodhound/dawgs/drivers/neo4j"
-	"github.com/specterops/bloodhound/dawgs/graph"
-	"github.com/specterops/bloodhound/graphschema/ad"
-	"github.com/specterops/bloodhound/graphschema/azure"
-	"github.com/specterops/bloodhound/graphschema/common"
-	"github.com/specterops/bloodhound/src/test"
-	"github.com/specterops/bloodhound/src/test/must"
+	"github.com/specterops/bloodhound/cmd/api/src/test"
+	"github.com/specterops/bloodhound/cmd/api/src/test/must"
+	"github.com/specterops/bloodhound/packages/go/graphschema/ad"
+	"github.com/specterops/bloodhound/packages/go/graphschema/azure"
+	"github.com/specterops/bloodhound/packages/go/graphschema/common"
+	_ "github.com/specterops/dawgs/drivers/neo4j"
+	"github.com/specterops/dawgs/graph"
 )
 
 var DefaultRelProperties = graph.AsProperties(graph.PropertyMap{
@@ -331,7 +331,17 @@ func (s *GraphTestContext) NewAzureTenant(tenantID string) *graph.Node {
 	}), azure.Entity, azure.Tenant)
 }
 
-func (s *GraphTestContext) NewActiveDirectoryDomain(name, objectID string, blocksInheritance, collected bool) *graph.Node {
+// NewAzureBase creates a new AZBase (azure.Entity) node
+func (s *GraphTestContext) NewAzureBase(name, objectID, tenantID string) *graph.Node {
+	return s.NewNode(graph.AsProperties(graph.PropertyMap{
+		common.Name:     name,
+		common.ObjectID: objectID,
+		azure.TenantID:  tenantID,
+		azure.License:   "license",
+	}), azure.Entity)
+}
+
+func (s *GraphTestContext) NewActiveDirectoryDomain(name, objectID string, blocksInheritance, collected bool, additionalKinds ...graph.Kind) *graph.Node {
 	if collected {
 		s.Harness.NumCollectedActiveDirectoryDomains++
 	}
@@ -342,7 +352,7 @@ func (s *GraphTestContext) NewActiveDirectoryDomain(name, objectID string, block
 		ad.DomainSID:         objectID,
 		common.Collected:     collected,
 		ad.BlocksInheritance: blocksInheritance,
-	}), ad.Entity, ad.Domain)
+	}), append(additionalKinds, ad.Entity, ad.Domain)...)
 }
 
 func (s *GraphTestContext) NewActiveDirectoryComputer(name, domainSID string) *graph.Node {
@@ -569,13 +579,13 @@ func (s *GraphTestContext) SetupActiveDirectory() {
 	s.Harness.RDP.Setup(s)
 	s.Harness.RDPB.Setup(s)
 
-	//startServer Session Harness
+	// startServer Session Harness
 	s.Harness.Session.Setup(s)
 
-	//startServer localgroup harness
+	// startServer localgroup harness
 	s.Harness.LocalGroupSQL.Setup(s)
 
-	//startServer control harnesses
+	// startServer control harnesses
 	s.Harness.OutboundControl.Setup(s)
 	s.Harness.InboundControl.Setup(s)
 
