@@ -34,6 +34,7 @@ export * from './Info';
 export * from './LineChart';
 export * from './Logout';
 export * from './MagnifyingGlass';
+export * from './Shield';
 export * from './SortAsc';
 export * from './SortDesc';
 export * from './SortEmpty';
@@ -41,3 +42,4 @@ export * from './TierZero';
 export * from './User';
 export * from './UserCog';
 export * from './VerticalEllipsis';
+export * from './Zones';
